Hawaii Appellate Court Opinions and Orders
Description: The official website of the Hawaii State Judiciary. Provides access to case records, forms, contact information and Appellate Court opinions
Keywords: hawaii judiciary, hawaii court, hawaii state judiciary, hawaii state court, hawaii court records, hawaii case records, hawaii court forms

Skip to main content | Skip to text menu

- General Information
  - Contact Information
  - Job Opportunities
  - Jury Service
  - Judiciary Overview
  - Court Administration
  - Business with Judiciary
- News & Reports
  - Press Releases
  - Legislative Update
  - Reports
  - In the Media
  - Oral Arguments
  - Media Guidelines
  - Speeches
- Self-Help
  - Court Forms
  - Traffic Cases
  - Self-Help Centers
  - Protective Orders
  - Mortgage Foreclosure
  - Small Claims
  - Regular Claims
  - Divorce
  - Landlord-Tenant Claims
  - Tips on Going to Court
- Services
  - ADA
  - Court Interpreting
  - Law Library
  - Mediation/ADR
  - Children's Justice Centers
  - Victim Services
  - Volunteer Settlement Master Process
  - Vehicle Tracker
- Courts
  - Supreme Court
  - Intermediate Court of Appeals
  - Circuit Court
  - District Court
  - Family Court
  - Land and Tax Appeal Courts
  - Administrative Adjudication
  - Commission on Judicial Conduct
  - Judicial Performance Reviews
  - Judicial Selection Commission
- Legal References
  - Search Court Records
  - Proposed Rules Changes
  - Supreme Court Various Orders
  - Opinions
  - Court Rules
  - Internet Resources
- Community Outreach
  - Civics Education
  - Volunteer Opportunities
  - Judiciary History Center
  - Divorce Law Seminar
  - Court Tours
  - Lunch 'N' Learn the Law
- Special Projects & Events
  - HOPE Probation
  - Girls Court

## I want to...

- Learn about the Courts
- Visit the Law Library
- See the Oral Argument Schedule
- Listen to an Oral Argument
- Read the Rules of Court
- Read Recent Appellate Opinions
- Request an ADA Accommodation
- Give Feedback

## Searches

- eCourt Kokua The Hawaii Judiciary is not affiliated with Sustain Technologies, Inc. or with eCourt®, which is a registered trademark of Sustain Technologies, Inc.
- Ho`ohiki For access to criminal and civil case information filed in the Circuit and Family courts and certain civil cases of the District Courts.
- Jobs Search for jobs at the Judiciary
- Efiling Case information.

## Status Updates

- Twitter Stream
- Facebook Fan Page
- YouTube Channel

#
Hawaii Appellate Court Opinions and Orders 2010

For 2009 and older, Case Number link will display content as an html page. PDF link will display a scanned image with file date stamp and judicial signatures. Beginning in 2010, Case Number link will display a scanned image with file date stamp and judicial signatures. ADA link will display an accessible file compatible with online reader devices.

Date | Ct. | Case Number | Case Name | Appealed From | Reporter Citation
--- | --- | --- | --- | --- | ---
12/30/2010 | ICA | 28627 [ADA] | In re Arbitration between United Public Workers, AFSCME, Local 646, AFL-CIO and State, Department of Transportation. | Circuit Court, 1st Circuit | 124 Haw. 372
12/30/2010 | ICA | 30257 [ADA] | In re KC (s.d.o., affirmed). | Family Court, 1st Circuit | 124 Haw. 366
12/30/2010 | ICA | CAAP-10-0000017 [ADA] | State v. Vaimili (Order Dismissing Appeal for Lack of Jurisdiction). | Circuit Court, 1st Circuit |
12/30/2010 | ICA | 29923 [ADA] | State v. Durham (Order re Appellant's Motion for Reconsideration). J. Nakamura Concurring and Dissenting. ICA s.d.o., filed 11/24/2010 [ada]. Dissent by J. Nakamura [ada]. Motion for Reconsideration, filed 12/06/2010. Petitioner-Appellant's Application for Writ of Certiorari, filed 02/02/2011. S.Ct. Order Accepting Application for Writ of Certiorari, filed 03/18/2011 [ada]. S.Ct. Opinion, filed 05/27/2011 [ada], 125 Haw. 114. Petitioner-Appellant's Motion for Reconsideration of Supreme Court Opinion filed on May 27, 2011, filed 06/06/2011. S.Ct. Order Granting Motion for Reconsideration in Part and Amending Opinion, filed 06/14/2011 [ada], 125 Haw. 249. | Circuit Court, 2nd Circuit |
12/30/2010 | ICA | 29177 [ADA] | In re Arbitration between United Public Workers, AFSCME, Local 646, AFL-CIO v. City and County of Honolulu, Department of Environmental Services, Collections System (Order of Correction). ICA s.d.o., filed 11/17/2010 [ada]. | Circuit Court, 1st Circuit |
12/29/2010 | ICA | 29993 [ADA] | State v. Tierney (s.d.o., affirmed). Petition for Writ of Certiorari, filed 01/11/2011. S.Ct. Order Dismissing Application for Writ of Certiorari, filed 01/18/2011 [ada]. Motion for Certified Question of Conflict, filed 01/20/2011. ICA Order Denying Motions for Reconsideration and to Review Petition for Writ of Habeas Corpus, filed 01/27/2011 [ada]. Petition for Writ of Certiorari, filed 01/27/2011. S.Ct. Order Rejecting Application for Writ of Certiorari, filed 03/07/2011 [ada]. S.Ct. Order, filed 03/09/2011 [ada]. Motion under Rule 60(b), (HRCP), filed 03/16/2011. S.Ct. Order, 03/18/2011 [ada]. S.Ct. Order, filed 03/18/2011 [ada]. | Circuit Court, 1st Circuit | 124 Haw. 425
12/29/2010 | ICA | CAAP-10-0000019 [ADA] | Drake v. Gaspar (Order Granting in Part and Denying in Part October 1, 2010 Motion for Dismissal of Appeal). | Circuit Court, 3rd Circuit |
12/28/2010 | ICA | 29407 [ADA] | O'Phelan v. Meek (s.d.o., affirmed). ICA Order of Correction, filed 01/24/2011 [ada]. | District Court, 3rd Circuit, North and South Hilo Division | 124 Haw. 425
12/28/2010 | ICA | 29569 [ADA] | Sarasota CCM, Inc. v. Levine (s.d.o., affirmed). | Circuit Court, 3rd Circuit | 124 Haw. 425
12/28/2010 | S.Ct | SCWC-29597 [ADA] | In re Tax Appeal of Compusa Stores, L.P. v. State of Hawaii, Department of Taxation (Order Accepting Application for Writ of Certiorari). ICA mem.op., filed 05/28/2010 [ada], 123 Haw. 299. Application for Writ of Certiorari, filed 11/22/2010. Motion for Reconsideration, filed 03/03/2011. S.Ct. Opinion, filed 02/14/2011 [ada], 128 Haw. 116. S.Ct. Order Denying Motion for Reconsideration, filed 03/09/2011 [ada]. | Tax Appeal Court |
12/27/2010 | S.Ct | SCWC-28255 [ADA] | State v. Chamberlain (Order Rejecting Application for Writ of Certiorari). ICA s.d.o., filed 07/26/2010 [ada], 123 Haw. 313. Application for Writ of Certiorari, filed 11/15/2010. | Circuit Court, 2nd Circuit |
01/04/2010 | ICA | 28583 [ADA] | State v. Torres (Order Granting Motion for Reconsideration to Correct Footnote and Amending Opinion). ICA Opinion, filed 12/15/2009 [pdf], 122 Haw. 2. ICA Order of Correction, filed 01/07/2010 [ada]. S.Ct. Order re: Applications for Writ of Certiorari, filed 05/24/2010 [ada]. Application for Motion for Reconsideration, filed 05/02/2011. S.Ct. Order Granting Motion for Reconsideration in Part, filed 06/30/2011 [ada], 125 Haw. 249. S.Ct. Amended Opinion, filed 08/09/2011 [ada], 125 Haw. 382. Amended Concurring and Dissenting Opinion by Acting C.J. Nakayama [ada]. | Circuit Court, 1st Circuit |

© 2008 Hawaii State Judiciary. All rights reserved.

Privacy Policy | Terms of Use | Accessibility Information